// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-10-13 00:20:50 +0200
package jnr.constants.platform.fake;
public enum AddressFamily implements jnr.constants.Constant {
AF_UNSPEC(1),
AF_LOCAL(2),
AF_UNIX(3),
AF_INET(4),
AF_IMPLINK(5),
AF_PUP(6),
AF_CHAOS(7),
AF_NS(8),
AF_ISO(9),
AF_OSI(10),
AF_ECMA(11),
AF_DATAKIT(12),
AF_CCITT(13),
AF_SNA(14),
AF_DECnet(15),
AF_DLI(16),
AF_LAT(17),
AF_HYLINK(18),
AF_APPLETALK(19),
AF_ROUTE(20),
AF_LINK(21),
pseudo_AF_XTP(22),
AF_COIP(23),
AF_CNT(24),
pseudo_AF_RTIP(25),
AF_IPX(26),
AF_SIP(27),
pseudo_AF_PIP(28),
AF_NDRV(29),
AF_ISDN(30),
AF_E164(31),
pseudo_AF_KEY(32),
AF_INET6(33),
AF_NATM(34),
AF_SYSTEM(35),
AF_NETBIOS(36),
AF_PPP(37),
AF_ATM(38),
pseudo_AF_HDRCMPLT(39),
AF_NETGRAPH(40),
AF_AX25(41),
AF_KEY(42),
AF_NETLINK(43),
AF_RDS(44),
AF_PPPOX(45),
AF_LLC(46),
AF_IB(47),
AF_MPLS(48),
AF_CAN(49),
AF_TIPC(50),
AF_BLUETOOTH(51),
AF_ALG(52),
AF_VSOCK(53),
AF_KCM(54),
AF_XDP(55),
AF_MAX(56);
private final long value;
private AddressFamily(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 56L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
