// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-09-20 16:28:49 +0000
package jnr.constants.platform.fake;
public enum INAddr implements jnr.constants.Constant {
INADDR_ANY(1),
INADDR_BROADCAST(2),
INADDR_NONE(3),
INADDR_LOOPBACK(4),
INADDR_UNSPEC_GROUP(5),
INADDR_ALLHOSTS_GROUP(6),
INADDR_ALLRTRS_GROUP(7),
INADDR_MAX_LOCAL_GROUP(8);
private final long value;
private INAddr(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 8L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
