// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-09-20 16:28:41 +0000
package jnr.constants.platform;
public enum Locale implements jnr.constants.Constant {
LC_CTYPE,
LC_NUMERIC,
LC_TIME,
LC_COLLATE,
LC_MONETARY,
LC_MESSAGES,
LC_ALL,
LC_PAPER,
LC_NAME,
LC_ADDRESS,
LC_TELEPHONE,
LC_MEASUREMENT,
LC_IDENTIFICATION,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<Locale> resolver = 
ConstantResolver.getResolver(Locale.class, 20000, 29999);
public final int value() { return (int) resolver.longValue(this); }
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return resolver.defined(this); }
public final String toString() { return description(); }
public static Locale valueOf(long value) { 
    return resolver.valueOf(value);
}
}
