// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:23 +0000
package jnr.constants.platform.aix;
public enum LangInfo implements jnr.constants.Constant {
CODESET(49L),
D_T_FMT(1L),
D_FMT(2L),
T_FMT(3L),
DAY_1(13L),
DAY_2(14L),
DAY_3(15L),
DAY_4(16L),
DAY_5(17L),
DAY_6(18L),
DAY_7(19L),
ABDAY_1(6L),
ABDAY_2(7L),
ABDAY_3(8L),
ABDAY_4(9L),
ABDAY_5(10L),
ABDAY_6(11L),
ABDAY_7(12L),
MON_1(32L),
MON_2(33L),
MON_3(34L),
MON_4(35L),
MON_5(36L),
MON_6(37L),
MON_7(38L),
MON_8(39L),
MON_9(40L),
MON_10(41L),
MON_11(42L),
MON_12(43L),
ABMON_1(20L),
ABMON_2(21L),
ABMON_3(22L),
ABMON_4(23L),
ABMON_5(24L),
ABMON_6(25L),
ABMON_7(26L),
ABMON_8(27L),
ABMON_9(28L),
ABMON_10(29L),
ABMON_11(30L),
ABMON_12(31L),
RADIXCHAR(44L),
THOUSEP(45L),
YESEXPR(61L),
NOEXPR(62L),
CRNCYSTR(48L);
private final long value;
private LangInfo(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 62L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
