require_relative '../../gen/ConstGenerator'
def gen_confstr_java(options)
  ConstGenerator.new 'platform.confstr', options do |cg|
    cg.include "sys/types.h"
    cg.include "unistd.h"
    %w[
      _CS_PATH
      _CS_POSIX_V7_ILP32_OFF32_CFLAGS
      _CS_POSIX_V7_ILP32_OFF32_LDFLAGS
      _CS_POSIX_V7_ILP32_OFF32_LIBS
      _CS_POSIX_V7_ILP32_OFFBIG_CFLAGS
      _CS_POSIX_V7_ILP32_OFFBIG_LDFLAGS
      _CS_POSIX_V7_ILP32_OFFBIG_LIBS
      _CS_POSIX_V7_LP64_OFF64_CFLAGS
      _CS_POSIX_V7_LP64_OFF64_LDFLAGS
      _CS_POSIX_V7_LP64_OFF64_LIBS
      _CS_POSIX_V7_LPBIG_OFFBIG_CFLAGS
      _CS_POSIX_V7_LPBIG_OFFBIG_LDFLAGS
      _CS_POSIX_V7_LPBIG_OFFBIG_LIBS
      _CS_POSIX_V7_WIDTH_RESTRICTED_ENVS
      _CS_V7_ENV
      _CS_POSIX_V6_ILP32_OFF32_CFLAGS
      _CS_POSIX_V6_ILP32_OFF32_LDFLAGS
      _CS_POSIX_V6_ILP32_OFF32_LIBS
      _CS_POSIX_V6_ILP32_OFFBIG_CFLAGS
      _CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS
      _CS_POSIX_V6_ILP32_OFFBIG_LIBS
      _CS_POSIX_V6_LP64_OFF64_CFLAGS
      _CS_POSIX_V6_LP64_OFF64_LDFLAGS
      _CS_POSIX_V6_LP64_OFF64_LIBS
      _CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS
      _CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS
      _CS_POSIX_V6_LPBIG_OFFBIG_LIBS
      _CS_POSIX_V6_WIDTH_RESTRICTED_ENVS
      _CS_V6_ENV
      _CS_GNU_LIBC_VERSION
      _CS_GNU_LIBPTHREAD_VERSION
    ].each {|c| cg.const(c) }
  end
end
