// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-06-03 11:07:36 +0800
package jnr.constants.platform.linux.loongarch64;
public enum RLIMIT implements jnr.constants.Constant {
RLIMIT_AS(9L),
RLIMIT_CORE(4L),
RLIMIT_CPU(0L),
RLIMIT_DATA(2L),
RLIMIT_FSIZE(1L),
RLIMIT_LOCKS(10L),
RLIMIT_MEMLOCK(8L),
RLIMIT_MSGQUEUE(12L),
RLIMIT_NICE(13L),
RLIMIT_NLIMITS(16L),
RLIMIT_NOFILE(7L),
RLIMIT_NPROC(6L),
RLIMIT_OFILE(7L),
RLIMIT_RSS(5L),
RLIMIT_RTPRIO(14L),
RLIMIT_RTTIME(15L),
RLIMIT_SIGPENDING(11L),
RLIMIT_STACK(3L);
private final long value;
private RLIMIT(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 16L;

static final class StringTable {
  public static final java.util.Map<RLIMIT, String> descriptions = generateTable();
  public static final java.util.Map<RLIMIT, String> generateTable() {
    java.util.Map<RLIMIT, String> map = new java.util.EnumMap<RLIMIT, String>(RLIMIT.class);
  map.put(RLIMIT_AS, "RLIMIT_AS");
  map.put(RLIMIT_CORE, "RLIMIT_CORE");
  map.put(RLIMIT_CPU, "RLIMIT_CPU");
  map.put(RLIMIT_DATA, "RLIMIT_DATA");
  map.put(RLIMIT_FSIZE, "RLIMIT_FSIZE");
  map.put(RLIMIT_LOCKS, "RLIMIT_LOCKS");
  map.put(RLIMIT_MEMLOCK, "RLIMIT_MEMLOCK");
  map.put(RLIMIT_MSGQUEUE, "RLIMIT_MSGQUEUE");
  map.put(RLIMIT_NICE, "RLIMIT_NICE");
  map.put(RLIMIT_NLIMITS, "RLIMIT_NLIMITS");
  map.put(RLIMIT_NOFILE, "RLIMIT_NOFILE");
  map.put(RLIMIT_NPROC, "RLIMIT_NPROC");
  map.put(RLIMIT_OFILE, "RLIMIT_OFILE");
  map.put(RLIMIT_RSS, "RLIMIT_RSS");
  map.put(RLIMIT_RTPRIO, "RLIMIT_RTPRIO");
  map.put(RLIMIT_RTTIME, "RLIMIT_RTTIME");
  map.put(RLIMIT_SIGPENDING, "RLIMIT_SIGPENDING");
  map.put(RLIMIT_STACK, "RLIMIT_STACK");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
