// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:34 +0000
package jnr.constants.platform.aix;
public enum RLIM implements jnr.constants.Constant {
RLIM_NLIMITS(0xaL),
RLIM_INFINITY(0x7fffffffffffffffL),
RLIM_SAVED_MAX(0x7ffffffffffffffeL),
RLIM_SAVED_CUR(0x7ffffffffffffffdL);
private final long value;
private RLIM(long value) { this.value = value; }
public static final long MIN_VALUE = 0xaL;
public static final long MAX_VALUE = 0x7fffffffffffffffL;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
