// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:46 +0000
package jnr.constants.platform.aix;
public enum TCP implements jnr.constants.Constant {
TCP_MAX_SACK(4L),
TCP_MSS(1460L),
// TCP_MINMSS not defined
// TCP_MINMSSOVERLOAD not defined
TCP_MAXWIN(65535L),
// TCP_MAX_WINSHIFT not defined
TCP_MAXBURST(8L),
// TCP_MAXHLEN not defined
// TCP_MAXOLEN not defined
TCP_NODELAY(1L),
TCP_MAXSEG(2L);
// TCP_NOPUSH not defined
// TCP_NOOPT not defined
// TCP_KEEPALIVE not defined
// TCP_NSTATES not defined
// TCP_RETRANSHZ not defined
private final long value;
private TCP(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 65535L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
