// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-09-16 23:31:26 +0200
package jnr.constants.platform.fake;
public enum Syslog implements jnr.constants.Constant {
LOG_ALERT(1),
LOG_AUTH(2),
LOG_AUTHPRIV(3),
LOG_CONS(4),
LOG_CONSOLE(5),
LOG_CRIT(6),
LOG_CRON(7),
LOG_DAEMON(8),
LOG_DEBUG(9),
LOG_EMERG(10),
LOG_ERR(11),
LOG_FTP(12),
LOG_INFO(13),
LOG_KERN(14),
LOG_LOCAL0(15),
LOG_LOCAL1(16),
LOG_LOCAL2(17),
LOG_LOCAL3(18),
LOG_LOCAL4(19),
LOG_LOCAL5(20),
LOG_LOCAL6(21),
LOG_LOCAL7(22),
LOG_LPR(23),
LOG_MAIL(24),
LOG_NDELAY(25),
LOG_NEWS(26),
LOG_NOTICE(27),
LOG_NOWAIT(28),
LOG_NTP(29),
LOG_ODELAY(30),
LOG_PERROR(31),
LOG_PID(32),
LOG_SECURITY(33),
LOG_SYSLOG(34),
LOG_USER(35),
LOG_UUCP(36),
LOG_WARNING(37);
private final long value;
private Syslog(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 37L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
