// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 01:01:55 +0200
package jnr.constants.platform.fake;
public enum ErrnoAddressInfo implements jnr.constants.Constant {
EAI_ADDRFAMILY(1),
EAI_AGAIN(2),
EAI_BADFLAGS(3),
EAI_FAIL(4),
EAI_FAMILY(5),
EAI_MEMORY(6),
EAI_NODATA(7),
EAI_NONAME(8),
EAI_OVERFLOW(9),
EAI_SERVICE(10),
EAI_SOCKTYPE(11),
EAI_SYSTEM(12),
EAI_BADHINTS(13),
EAI_PROTOCOL(14),
EAI_MAX(15);
private final long value;
private ErrnoAddressInfo(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 15L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
