// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-09-20 19:03:25 +0200
package jnr.constants.platform.windows;
public enum Signal implements jnr.constants.Constant {
SIGINT(2L),
// SIGHUP not defined
// SIGQUIT not defined
SIGILL(4L),
// SIGTRAP not defined
SIGABRT(22L),
// SIGIOT not defined
// SIGBUS not defined
SIGFPE(8L),
// SIGKILL not defined
// SIGUSR1 not defined
SIGSEGV(11L),
// SIGUSR2 not defined
// SIGPIPE not defined
// SIGALRM not defined
SIGTERM(15L),
// SIGSTKFLT not defined
// SIGCLD not defined
// SIGCHLD not defined
// SIGCONT not defined
// SIGSTOP not defined
// SIGTSTP not defined
// SIGTTIN not defined
// SIGTTOU not defined
// SIGURG not defined
// SIGXCPU not defined
// SIGXFSZ not defined
// SIGVTALRM not defined
// SIGPROF not defined
// SIGWINCH not defined
// SIGPOLL not defined
// SIGIO not defined
// SIGPWR not defined
// SIGSYS not defined
// SIGUNUSED not defined
// SIGRTMIN not defined
// SIGRTMAX not defined
NSIG(23L);
private final long value;
private Signal(long value) { this.value = value; }
public static final long MIN_VALUE = 2L;
public static final long MAX_VALUE = 23L;

static final class StringTable {
  public static final java.util.Map<Signal, String> descriptions = generateTable();
  public static final java.util.Map<Signal, String> generateTable() {
    java.util.Map<Signal, String> map = new java.util.EnumMap<Signal, String>(Signal.class);
  map.put(SIGINT, "SIGINT");
  map.put(SIGILL, "SIGILL");
  map.put(SIGABRT, "SIGABRT");
  map.put(SIGFPE, "SIGFPE");
  map.put(SIGSEGV, "SIGSEGV");
  map.put(SIGTERM, "SIGTERM");
  map.put(NSIG, "NSIG");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
