// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 01:01:54 +0200
package jnr.constants.platform.fake;
public enum AddressInfo implements jnr.constants.Constant {
AI_PASSIVE(1),
AI_CANONNAME(2),
AI_NUMERICHOST(3),
AI_NUMERICSERV(4),
AI_MASK(5),
AI_ALL(6),
AI_V4MAPPED_CFG(7),
AI_ADDRCONFIG(8),
AI_V4MAPPED(9),
AI_DEFAULT(10);
private final long value;
private AddressInfo(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 10L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
