// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-06-04 16:59:44 +0200
package jnr.constants.platform.fake;
public enum Pathconf implements jnr.constants.Constant {
_PC_FILESIZEBITS(1),
_PC_LINK_MAX(2),
_PC_MAX_CANON(3),
_PC_MAX_INPUT(4),
_PC_NAME_MAX(5),
_PC_PATH_MAX(6),
_PC_PIPE_BUF(7),
_PC_2_SYMLINKS(8),
_PC_ALLOC_SIZE_MIN(9),
_PC_REC_INCR_XFER_SIZE(10),
_PC_REC_MAX_XFER_SIZE(11),
_PC_REC_MIN_XFER_SIZE(12),
_PC_REC_XFER_ALIGN(13),
_PC_SYMLINK_MAX(14),
_PC_CHOWN_RESTRICTED(15),
_PC_NO_TRUNC(16),
_PC_VDISABLE(17),
_PC_ASYNC_IO(18),
_PC_PRIO_IO(19),
_PC_SYNC_IO(20);
private final long value;
private Pathconf(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 20L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
