// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 03:20:18 +0200
package jnr.constants.platform.windows;
public enum IP implements jnr.constants.Constant {
IP_OPTIONS(1L),
// IP_HDRINCL not defined
IP_TOS(8L),
IP_TTL(7L),
// IP_RECVOPTS not defined
// IP_RECVRETOPTS not defined
// IP_RECVDSTADDR not defined
// IP_RETOPTS not defined
// IP_MINTTL not defined
// IP_DONTFRAG not defined
// IP_SENDSRCADDR not defined
// IP_ONESBCAST not defined
// IP_RECVTTL not defined
// IP_RECVIF not defined
// IP_RECVSLLA not defined
// IP_PORTRANGE not defined
IP_MULTICAST_IF(2L),
IP_MULTICAST_TTL(3L),
IP_MULTICAST_LOOP(4L),
IP_ADD_MEMBERSHIP(5L),
IP_DROP_MEMBERSHIP(6L),
IP_DEFAULT_MULTICAST_TTL(1L),
IP_DEFAULT_MULTICAST_LOOP(1L),
IP_MAX_MEMBERSHIPS(20L);
// IP_ROUTER_ALERT not defined
// IP_PKTINFO not defined
// IP_PKTOPTIONS not defined
// IP_MTU_DISCOVER not defined
// IP_RECVERR not defined
// IP_RECVTOS not defined
// IP_MTU not defined
// IP_FREEBIND not defined
// IP_IPSEC_POLICY not defined
// IP_XFRM_POLICY not defined
// IP_PASSSEC not defined
// IP_TRANSPARENT not defined
// IP_PMTUDISC_DONT not defined
// IP_PMTUDISC_WANT not defined
// IP_PMTUDISC_DO not defined
// IP_UNBLOCK_SOURCE not defined
// IP_BLOCK_SOURCE not defined
// IP_ADD_SOURCE_MEMBERSHIP not defined
// IP_DROP_SOURCE_MEMBERSHIP not defined
// IP_MSFILTER not defined
private final long value;
private IP(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 20L;

static final class StringTable {
  public static final java.util.Map<IP, String> descriptions = generateTable();
  public static final java.util.Map<IP, String> generateTable() {
    java.util.Map<IP, String> map = new java.util.EnumMap<IP, String>(IP.class);
  map.put(IP_OPTIONS, "IP_OPTIONS");
  map.put(IP_TOS, "IP_TOS");
  map.put(IP_TTL, "IP_TTL");
  map.put(IP_MULTICAST_IF, "IP_MULTICAST_IF");
  map.put(IP_MULTICAST_TTL, "IP_MULTICAST_TTL");
  map.put(IP_MULTICAST_LOOP, "IP_MULTICAST_LOOP");
  map.put(IP_ADD_MEMBERSHIP, "IP_ADD_MEMBERSHIP");
  map.put(IP_DROP_MEMBERSHIP, "IP_DROP_MEMBERSHIP");
  map.put(IP_DEFAULT_MULTICAST_TTL, "IP_DEFAULT_MULTICAST_TTL");
  map.put(IP_DEFAULT_MULTICAST_LOOP, "IP_DEFAULT_MULTICAST_LOOP");
  map.put(IP_MAX_MEMBERSHIPS, "IP_MAX_MEMBERSHIPS");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
