// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-10-08 17:37:36 +0200
package jnr.constants.platform.freebsd.aarch64;
public enum UDP implements jnr.constants.Constant {
;
// UDP_CORK not defined
private final long value;
private UDP(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 0L;

public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
