// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-09 13:19:51 -0500
package jnr.constants.platform.darwin;
public enum Local implements jnr.constants.Constant {
LOCAL_PEERCRED(1L);
// LOCAL_CREDS not defined
// LOCAL_CONNWAIT not defined
private final long value;
private Local(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 1L;

static final class StringTable {
  public static final java.util.Map<Local, String> descriptions = generateTable();
  public static final java.util.Map<Local, String> generateTable() {
    java.util.Map<Local, String> map = new java.util.EnumMap<Local, String>(Local.class);
  map.put(LOCAL_PEERCRED, "LOCAL_PEERCRED");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
