// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:24 +0000
package jnr.constants.platform.aix;
public enum Locale implements jnr.constants.Constant {
LC_CTYPE(1L),
LC_NUMERIC(3L),
LC_TIME(4L),
LC_COLLATE(0L),
LC_MONETARY(2L),
LC_MESSAGES(5L),
LC_ALL(-1L);
// LC_PAPER not defined
// LC_NAME not defined
// LC_ADDRESS not defined
// LC_TELEPHONE not defined
// LC_MEASUREMENT not defined
// LC_IDENTIFICATION not defined
private final long value;
private Locale(long value) { this.value = value; }
public static final long MIN_VALUE = -1L;
public static final long MAX_VALUE = 5L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
