// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:27 +0000
package jnr.constants.platform.aix;
public enum OpenFlags implements jnr.constants.Constant {
O_RDONLY(0L),
O_WRONLY(1L),
O_RDWR(2L),
O_ACCMODE(3L),
O_NONBLOCK(4L),
O_APPEND(8L),
O_SYNC(16L),
// O_SHLOCK not defined
// O_EXLOCK not defined
// O_ASYNC not defined
// O_FSYNC not defined
// O_NOFOLLOW not defined
O_CREAT(256L),
O_TRUNC(512L),
O_EXCL(1024L),
// O_EVTONLY not defined
O_DIRECTORY(524288L),
// O_SYMLINK not defined
// O_BINARY not defined
O_NOCTTY(2048L);
// O_TMPFILE not defined
// O_CLOEXEC not defined
private final long value;
private OpenFlags(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 524288L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
