// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-19 00:15:32 +0000
package jnr.constants.platform.freebsd;
public enum Confstr implements jnr.constants.Constant {
_CS_PATH(1L),
// _CS_POSIX_V7_ILP32_OFF32_CFLAGS not defined
// _CS_POSIX_V7_ILP32_OFF32_LDFLAGS not defined
// _CS_POSIX_V7_ILP32_OFF32_LIBS not defined
// _CS_POSIX_V7_ILP32_OFFBIG_CFLAGS not defined
// _CS_POSIX_V7_ILP32_OFFBIG_LDFLAGS not defined
// _CS_POSIX_V7_ILP32_OFFBIG_LIBS not defined
// _CS_POSIX_V7_LP64_OFF64_CFLAGS not defined
// _CS_POSIX_V7_LP64_OFF64_LDFLAGS not defined
// _CS_POSIX_V7_LP64_OFF64_LIBS not defined
// _CS_POSIX_V7_LPBIG_OFFBIG_CFLAGS not defined
// _CS_POSIX_V7_LPBIG_OFFBIG_LDFLAGS not defined
// _CS_POSIX_V7_LPBIG_OFFBIG_LIBS not defined
// _CS_POSIX_V7_WIDTH_RESTRICTED_ENVS not defined
// _CS_V7_ENV not defined
_CS_POSIX_V6_ILP32_OFF32_CFLAGS(2L),
_CS_POSIX_V6_ILP32_OFF32_LDFLAGS(3L),
_CS_POSIX_V6_ILP32_OFF32_LIBS(4L),
_CS_POSIX_V6_ILP32_OFFBIG_CFLAGS(5L),
_CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS(6L),
_CS_POSIX_V6_ILP32_OFFBIG_LIBS(7L),
_CS_POSIX_V6_LP64_OFF64_CFLAGS(8L),
_CS_POSIX_V6_LP64_OFF64_LDFLAGS(9L),
_CS_POSIX_V6_LP64_OFF64_LIBS(10L),
_CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS(11L),
_CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS(12L),
_CS_POSIX_V6_LPBIG_OFFBIG_LIBS(13L),
_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS(14L);
// _CS_V6_ENV not defined
// _CS_GNU_LIBC_VERSION not defined
// _CS_GNU_LIBPTHREAD_VERSION not defined
private final long value;
private Confstr(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 14L;

static final class StringTable {
  public static final java.util.Map<Confstr, String> descriptions = generateTable();
  public static final java.util.Map<Confstr, String> generateTable() {
    java.util.Map<Confstr, String> map = new java.util.EnumMap<Confstr, String>(Confstr.class);
  map.put(_CS_PATH, "_CS_PATH");
  map.put(_CS_POSIX_V6_ILP32_OFF32_CFLAGS, "_CS_POSIX_V6_ILP32_OFF32_CFLAGS");
  map.put(_CS_POSIX_V6_ILP32_OFF32_LDFLAGS, "_CS_POSIX_V6_ILP32_OFF32_LDFLAGS");
  map.put(_CS_POSIX_V6_ILP32_OFF32_LIBS, "_CS_POSIX_V6_ILP32_OFF32_LIBS");
  map.put(_CS_POSIX_V6_ILP32_OFFBIG_CFLAGS, "_CS_POSIX_V6_ILP32_OFFBIG_CFLAGS");
  map.put(_CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS, "_CS_POSIX_V6_ILP32_OFFBIG_LDFLAGS");
  map.put(_CS_POSIX_V6_ILP32_OFFBIG_LIBS, "_CS_POSIX_V6_ILP32_OFFBIG_LIBS");
  map.put(_CS_POSIX_V6_LP64_OFF64_CFLAGS, "_CS_POSIX_V6_LP64_OFF64_CFLAGS");
  map.put(_CS_POSIX_V6_LP64_OFF64_LDFLAGS, "_CS_POSIX_V6_LP64_OFF64_LDFLAGS");
  map.put(_CS_POSIX_V6_LP64_OFF64_LIBS, "_CS_POSIX_V6_LP64_OFF64_LIBS");
  map.put(_CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS, "_CS_POSIX_V6_LPBIG_OFFBIG_CFLAGS");
  map.put(_CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS, "_CS_POSIX_V6_LPBIG_OFFBIG_LDFLAGS");
  map.put(_CS_POSIX_V6_LPBIG_OFFBIG_LIBS, "_CS_POSIX_V6_LPBIG_OFFBIG_LIBS");
  map.put(_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS, "_CS_POSIX_V6_WIDTH_RESTRICTED_ENVS");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
