// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-09-20 16:28:49 +0000
package jnr.constants.platform.fake;
public enum NameInfo implements jnr.constants.Constant {
NI_MAXHOST(1),
NI_MAXSERV(2),
NI_NOFQDN(3),
NI_NUMERICHOST(4),
NI_NAMEREQD(5),
NI_NUMERICSERV(6),
NI_DGRAM(7),
NI_WITHSCOPEID(8);
private final long value;
private NameInfo(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 8L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
