// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 01:01:39 +0200
package jnr.constants.platform;
public enum ErrnoAddressInfo implements jnr.constants.Constant {
EAI_ADDRFAMILY,
EAI_AGAIN,
EAI_BADFLAGS,
EAI_FAIL,
EAI_FAMILY,
EAI_MEMORY,
EAI_NODATA,
EAI_NONAME,
EAI_OVERFLOW,
EAI_SERVICE,
EAI_SOCKTYPE,
EAI_SYSTEM,
EAI_BADHINTS,
EAI_PROTOCOL,
EAI_MAX,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<ErrnoAddressInfo> resolver = 
ConstantResolver.getResolver(ErrnoAddressInfo.class, 20000, 29999);
public final int value() { return (int) resolver.longValue(this); }
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return resolver.defined(this); }
public final String toString() { return description(); }
public static ErrnoAddressInfo valueOf(long value) { 
    return resolver.valueOf(value);
}
}
