// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-09-20 14:44:25 -0600
package jnr.constants.platform.openbsd;
public enum WaitFlags implements jnr.constants.Constant {
WNOHANG(0x1L),
WUNTRACED(0x2L),
// WSTOPPED not defined
// WEXITED not defined
WCONTINUED(0x8L);
// WNOWAIT not defined
private final long value;
private WaitFlags(long value) { this.value = value; }
public static final long MIN_VALUE = 0x1L;
public static final long MAX_VALUE = 0x8L;

static final class StringTable {
  public static final java.util.Map<WaitFlags, String> descriptions = generateTable();
  public static final java.util.Map<WaitFlags, String> generateTable() {
    java.util.Map<WaitFlags, String> map = new java.util.EnumMap<WaitFlags, String>(WaitFlags.class);
  map.put(WNOHANG, "WNOHANG");
  map.put(WUNTRACED, "WUNTRACED");
  map.put(WCONTINUED, "WCONTINUED");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
