// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-08-29 19:11:01 +0200
package jnr.constants.platform.fake;
public enum SocketMessage implements jnr.constants.Constant {
MSG_DONTWAIT(1),
MSG_OOB(2),
MSG_PEEK(3),
MSG_DONTROUTE(4),
MSG_EOR(5),
MSG_TRUNC(6),
MSG_CTRUNC(7),
MSG_WAITALL(8),
MSG_PROXY(9),
MSG_FIN(10),
MSG_SYN(11),
MSG_CONFIRM(12),
MSG_RST(13),
MSG_ERRQUEUE(14),
MSG_NOSIGNAL(15),
MSG_MORE(16),
MSG_FASTOPEN(17),
MSG_EOF(18),
MSG_FLUSH(19),
MSG_HOLD(20),
MSG_SEND(21),
MSG_HAVEMORE(22),
MSG_RCVMORE(23),
MSG_COMPAT(24);
private final long value;
private SocketMessage(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 24L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
