// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-09 13:19:50 -0500
package jnr.constants.platform.darwin;
public enum IPv6 implements jnr.constants.Constant {
IPV6_JOIN_GROUP(12L),
IPV6_LEAVE_GROUP(13L),
IPV6_MULTICAST_HOPS(10L),
IPV6_MULTICAST_IF(9L),
IPV6_MULTICAST_LOOP(11L),
IPV6_UNICAST_HOPS(4L),
IPV6_V6ONLY(27L),
IPV6_CHECKSUM(26L),
// IPV6_DONTFRAG not defined
// IPV6_DSTOPTS not defined
// IPV6_HOPLIMIT not defined
// IPV6_HOPOPTS not defined
// IPV6_NEXTHOP not defined
// IPV6_PATHMTU not defined
// IPV6_PKTINFO not defined
// IPV6_RECVDSTOPTS not defined
// IPV6_RECVHOPLIMIT not defined
// IPV6_RECVHOPOPTS not defined
// IPV6_RECVPKTINFO not defined
// IPV6_RECVRTHDR not defined
IPV6_RECVTCLASS(35L),
// IPV6_RTHDR not defined
// IPV6_RTHDRDSTOPTS not defined
IPV6_RTHDR_TYPE_0(0L),
// IPV6_RECVPATHMTU not defined
IPV6_TCLASS(36L);
// IPV6_USE_MIN_MTU not defined
private final long value;
private IPv6(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 36L;

static final class StringTable {
  public static final java.util.Map<IPv6, String> descriptions = generateTable();
  public static final java.util.Map<IPv6, String> generateTable() {
    java.util.Map<IPv6, String> map = new java.util.EnumMap<IPv6, String>(IPv6.class);
  map.put(IPV6_JOIN_GROUP, "IPV6_JOIN_GROUP");
  map.put(IPV6_LEAVE_GROUP, "IPV6_LEAVE_GROUP");
  map.put(IPV6_MULTICAST_HOPS, "IPV6_MULTICAST_HOPS");
  map.put(IPV6_MULTICAST_IF, "IPV6_MULTICAST_IF");
  map.put(IPV6_MULTICAST_LOOP, "IPV6_MULTICAST_LOOP");
  map.put(IPV6_UNICAST_HOPS, "IPV6_UNICAST_HOPS");
  map.put(IPV6_V6ONLY, "IPV6_V6ONLY");
  map.put(IPV6_CHECKSUM, "IPV6_CHECKSUM");
  map.put(IPV6_RECVTCLASS, "IPV6_RECVTCLASS");
  map.put(IPV6_RTHDR_TYPE_0, "IPV6_RTHDR_TYPE_0");
  map.put(IPV6_TCLASS, "IPV6_TCLASS");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
