// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:15 +0000
package jnr.constants.platform.aix;
public enum AddressFamily implements jnr.constants.Constant {
AF_UNSPEC(0L),
// AF_LOCAL not defined
AF_UNIX(1L),
AF_INET(2L),
AF_IMPLINK(3L),
AF_PUP(4L),
AF_CHAOS(5L),
AF_NS(6L),
AF_ISO(7L),
AF_OSI(7L),
AF_ECMA(8L),
AF_DATAKIT(9L),
AF_CCITT(10L),
AF_SNA(11L),
AF_DECnet(12L),
AF_DLI(13L),
AF_LAT(14L),
AF_HYLINK(15L),
AF_APPLETALK(16L),
AF_ROUTE(17L),
AF_LINK(18L),
pseudo_AF_XTP(19L),
// AF_COIP not defined
// AF_CNT not defined
// pseudo_AF_RTIP not defined
// AF_IPX not defined
// AF_SIP not defined
// pseudo_AF_PIP not defined
// AF_NDRV not defined
// AF_ISDN not defined
// AF_E164 not defined
// pseudo_AF_KEY not defined
AF_INET6(24L),
// AF_NATM not defined
// AF_SYSTEM not defined
// AF_NETBIOS not defined
// AF_PPP not defined
// AF_ATM not defined
// pseudo_AF_HDRCMPLT not defined
// AF_NETGRAPH not defined
// AF_AX25 not defined
AF_MAX(30L);
private final long value;
private AddressFamily(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 30L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
