// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2018-05-11 03:41:48 +0000
package jnr.constants.platform.aix;
public enum WaitFlags implements jnr.constants.Constant {
WNOHANG(0x1L),
WUNTRACED(0x2L),
WSTOPPED(0x40L),
WEXITED(0x4L),
WCONTINUED(0x1000000L),
WNOWAIT(0x10L);
private final long value;
private WaitFlags(long value) { this.value = value; }
public static final long MIN_VALUE = 0x1L;
public static final long MAX_VALUE = 0x1000000L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
