// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-06-03 02:37:57 +0000
package jnr.constants.platform.linux.powerpc64;
public enum UDP implements jnr.constants.Constant {
UDP_CORK(1L);
private final long value;
private UDP(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 1L;

static final class StringTable {
  public static final java.util.Map<UDP, String> descriptions = generateTable();
  public static final java.util.Map<UDP, String> generateTable() {
    java.util.Map<UDP, String> map = new java.util.EnumMap<UDP, String>(UDP.class);
  map.put(UDP_CORK, "UDP_CORK");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
