// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 01:01:58 +0200
package jnr.constants.platform.fake;
public enum Multicast implements jnr.constants.Constant {
MCAST_JOIN_GROUP(1),
MCAST_BLOCK_SOURCE(2),
MCAST_UNBLOCK_SOURCE(3),
MCAST_LEAVE_GROUP(4),
MCAST_JOIN_SOURCE_GROUP(5),
MCAST_LEAVE_SOURCE_GROUP(6),
MCAST_MSFILTER(7),
MCAST_EXCLUDE(8),
MCAST_INCLUDE(9);
private final long value;
private Multicast(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 9L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
