// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-06-03 00:56:21 +0000
package jnr.constants.platform.linux.mips64el;
public enum AddressInfo implements jnr.constants.Constant {
AI_PASSIVE(1L),
AI_CANONNAME(2L),
AI_NUMERICHOST(4L),
AI_NUMERICSERV(1024L),
// AI_MASK not defined
AI_ALL(16L),
// AI_V4MAPPED_CFG not defined
AI_ADDRCONFIG(32L),
AI_V4MAPPED(8L);
// AI_DEFAULT not defined
private final long value;
private AddressInfo(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 1024L;

static final class StringTable {
  public static final java.util.Map<AddressInfo, String> descriptions = generateTable();
  public static final java.util.Map<AddressInfo, String> generateTable() {
    java.util.Map<AddressInfo, String> map = new java.util.EnumMap<AddressInfo, String>(AddressInfo.class);
  map.put(AI_PASSIVE, "AI_PASSIVE");
  map.put(AI_CANONNAME, "AI_CANONNAME");
  map.put(AI_NUMERICHOST, "AI_NUMERICHOST");
  map.put(AI_NUMERICSERV, "AI_NUMERICSERV");
  map.put(AI_ALL, "AI_ALL");
  map.put(AI_ADDRCONFIG, "AI_ADDRCONFIG");
  map.put(AI_V4MAPPED, "AI_V4MAPPED");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
