// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-08-29 19:10:25 +0200
package jnr.constants.platform;
public enum SocketMessage implements jnr.constants.Constant {
MSG_DONTWAIT,
MSG_OOB,
MSG_PEEK,
MSG_DONTROUTE,
MSG_EOR,
MSG_TRUNC,
MSG_CTRUNC,
MSG_WAITALL,
MSG_PROXY,
MSG_FIN,
MSG_SYN,
MSG_CONFIRM,
MSG_RST,
MSG_ERRQUEUE,
MSG_NOSIGNAL,
MSG_MORE,
MSG_FASTOPEN,
MSG_EOF,
MSG_FLUSH,
MSG_HOLD,
MSG_SEND,
MSG_HAVEMORE,
MSG_RCVMORE,
MSG_COMPAT,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<SocketMessage> resolver = 
ConstantResolver.getResolver(SocketMessage.class, 20000, 29999);
public final int value() { return (int) resolver.longValue(this); }
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return resolver.defined(this); }
public final String toString() { return description(); }
public static SocketMessage valueOf(long value) { 
    return resolver.valueOf(value);
}
}
