// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2021-06-03 11:07:35 +0800
package jnr.constants.platform.linux.loongarch64;
public enum SocketLevel implements jnr.constants.Constant {
SOL_SOCKET(1L),
SOL_IP(0L),
SOL_TCP(6L),
SOL_UDP(17L),
SOL_IPV6(41L);
private final long value;
private SocketLevel(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 41L;

static final class StringTable {
  public static final java.util.Map<SocketLevel, String> descriptions = generateTable();
  public static final java.util.Map<SocketLevel, String> generateTable() {
    java.util.Map<SocketLevel, String> map = new java.util.EnumMap<SocketLevel, String>(SocketLevel.class);
  map.put(SOL_SOCKET, "SOL_SOCKET");
  map.put(SOL_IP, "SOL_IP");
  map.put(SOL_TCP, "SOL_TCP");
  map.put(SOL_UDP, "SOL_UDP");
  map.put(SOL_IPV6, "SOL_IPV6");
    return map;
  }
}
public final String toString() { return StringTable.descriptions.get(this); }
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
