// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 01:01:56 +0200
package jnr.constants.platform.fake;
public enum INet6 implements jnr.constants.Constant {
INET6_ADDRSTRLEN(1);
private final long value;
private INet6(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 1L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
