// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2020-09-03 01:02:01 +0200
package jnr.constants.platform.fake;
public enum SocketControlMessage implements jnr.constants.Constant {
SCM_RIGHTS(1),
SCM_TIMESTAMP(2),
SCM_TIMESTAMPNS(3),
SCM_TIMESTAMPING(4),
SCM_BINTIME(5),
SCM_CREDENTIALS(6),
SCM_CREDS(7),
SCM_UCRED(8),
SCM_WIFI_STATUS(9);
private final long value;
private SocketControlMessage(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 9L;
public final int value() { return (int) value; }
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
